@@ -6,7 +6,7 @@
 #
 
 package File::ByLine;
-$File::ByLine::VERSION = '1.182360'; # TRIAL
+$File::ByLine::VERSION = '1.182362'; # TRIAL
 use v5.10;
 
 # ABSTRACT: Line-by-line file access loops
@@ -32,11 +32,11 @@ our @ISA = qw(Exporter);
 
 ## no critic (Modules::ProhibitAutomaticExportation)
 our @EXPORT =
-  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines writefile);
+  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines writefile appendfile);
 ## use critic
 
 our @EXPORT_OK =
-  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines writefile);
+  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines writefile appendfile);
 
 
 sub dolines (&$) {
@@ -154,6 +154,23 @@ sub writefile ($@) {
     return;
 }
 
+
+sub appendfile ($@) {
+    my ( $file, @lines ) = @_;
+    if ( !defined($file) ) { die("Must define the filename"); }
+
+    # Last line should have it's newline removed, if applicable
+    if (@lines) { $lines[-1] =~ s/\n$//s; }
+
+    open my $fh, '>>', $file;
+    foreach my $line (@lines) {
+        say $fh $line;
+    }
+    close $fh;
+
+    return;
+}
+
 #
 # Object Oriented Interface
 #
@@ -179,7 +196,7 @@ File::ByLine - Line-by-line file access loops
 
 =head1 VERSION
 
-version 1.182360
+version 1.182362
 
 =head1 SYNOPSIS
 
@@ -214,6 +231,9 @@ version 1.182360
   # Write out a file
   writefile "file.txt", @lines;  # Since version 2.182360
 
+  # Append to a file
+  appendfile "file.txt", @lines; # Since version 2.182362
+
   #
   # Object Oriented Interface (More Powerful!)
   #
@@ -317,7 +337,7 @@ not orthogonal with the C<maplines()>/C<greplines()> routines.
 
 Requires L<Parallel::WorkUnit> to be installed.
 
-Three parameters are requied: a codref, a filename, and number of simultanious
+Three parameters are required: a codref, a filename, and number of simultanious
 child threads to use.
 
 Instead of a single filename, an arrayref can be passed in, in which case the
@@ -353,7 +373,7 @@ from C<parallel_forlines()>.
 
 Requires L<Parallel::WorkUnit> to be installed.
 
-Three parameters are requied: a filename, a codref, and number of simultanious
+Three parameters are required: a filename, a codref, and number of simultanious
 child threads to use.
 
 Instead of a single filename, an arrayref can be passed in, in which case the
@@ -403,7 +423,7 @@ This function returns the lines for which the coderef evaluates as true.
 
   my (@result) = parallel_greplines { m/foo/ } "file.txt", 10;
 
-Three parameters are requied: a coderef, filename, and number of simultanious
+Three parameters are required: a coderef, filename, and number of simultanious
 child threads to use.
 
 Instead of a single filename, an arrayref can be passed in, in which case the
@@ -464,7 +484,7 @@ This function returns the lines for which the coderef evaluates as true.
 
   my (@result) = parallel_maplines { lc($_) } "file.txt", 10;
 
-Three parameters are requied: a coderef, filename, and number of simultanious
+Three parameters are required: a coderef, filename, and number of simultanious
 child threads to use.
 
 Instead of a single filename, an arrayref can be passed in, in which case the
@@ -522,6 +542,30 @@ There is no object-oriented equivilent to this function.
 
 This does not return any value.
 
+=head2 appendfile
+
+  appendfile "file.txt", @lines;
+
+This was added in version 2.181862.
+
+This function creates or appends to a file (appending on existing files) and
+writes each line to the end of the file.  Each line (array element) is
+terminated with a newline, except the last line IF the last line ends in a
+newline itself.
+
+I.E. the following will append to a file with three lines, each terminated by
+a newline:
+
+  appendfile "file.txt", "a", "b", "c";
+
+So will this:
+
+  appendfile "file.txt", "a\nb", "c\n";
+
+There is no object-oriented equivilent to this function.
+
+This does not return any value.
+
 =head1 OBJECT ORIENTED INTERFACE
 
 The object oriented interface was implemented in version 1.181860.
